@@ -1,7 +1,7 @@
 package App::ListOrgHeadlinesFast;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.32'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.33'; # VERSION
 
 use 5.010;
 use strict;
@@ -96,18 +96,16 @@ App::ListOrgHeadlinesFast - List & count Org headlines & todos
 
 =head1 VERSION
 
-This document describes version 0.32 of App::ListOrgHeadlinesFast (from Perl distribution App-OrgUtils), released on 2015-08-17.
+This document describes version 0.33 of App::ListOrgHeadlinesFast (from Perl distribution App-OrgUtils), released on 2015-09-03.
 
 =head1 FUNCTIONS
 
 
 =head2 count_org_headlines(%args) -> int
 
-{en_US Count Org headlines}.
+Count Org headlines.
 
-{en_US 
 This routine uses simple regex instead of Org::Parser, for faster performance.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -115,37 +113,31 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ascendant_match> => I<str|re>
 
-{en_US Only include headline whose ascendant matches this}.
+Only include headline whose ascendant matches this.
 
-{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
-}
 
 =item * B<input>* => I<str>
 
-{en_US 
 Value is either a string or an array of strings.
-}
 
 =item * B<is_done> => I<bool>
 
-{en_US Only include headline which is a done todo item}.
+Only include headline which is a done todo item.
 
 =item * B<is_todo> => I<bool>
 
-{en_US Only include headline which is a todo item}.
+Only include headline which is a todo item.
 
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
 
-{en_US Only include headline which matches this}.
+Only include headline which matches this.
 
-{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
-}
 
 =item * B<max_level> => I<int>
 
@@ -153,12 +145,10 @@ C</.../i> it is assumed to be a regex.
 
 =item * B<parent_match> => I<str|re>
 
-{en_US Only include headline whose parent matches this}.
+Only include headline whose parent matches this.
 
-{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
-}
 
 =back
 
@@ -167,11 +157,9 @@ Return value:  (int)
 
 =head2 count_org_todos(%args) -> int
 
-{en_US Count Org todos}.
+Count Org todos.
 
-{en_US 
 This routine uses simple regex instead of Org::Parser, for faster performance.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -179,33 +167,27 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ascendant_match> => I<str|re>
 
-{en_US Only include headline whose ascendant matches this}.
+Only include headline whose ascendant matches this.
 
-{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
-}
 
 =item * B<input>* => I<str>
 
-{en_US 
 Value is either a string or an array of strings.
-}
 
 =item * B<is_done> => I<bool>
 
-{en_US Only include headline which is a done todo item}.
+Only include headline which is a done todo item.
 
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
 
-{en_US Only include headline which matches this}.
+Only include headline which matches this.
 
-{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
-}
 
 =item * B<max_level> => I<int>
 
@@ -213,12 +195,10 @@ C</.../i> it is assumed to be a regex.
 
 =item * B<parent_match> => I<str|re>
 
-{en_US Only include headline whose parent matches this}.
+Only include headline whose parent matches this.
 
-{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
-}
 
 =back
 
@@ -227,11 +207,9 @@ Return value:  (int)
 
 =head2 list_org_headlines(%args) -> array[str]
 
-{en_US List Org headlines}.
+List Org headlines.
 
-{en_US 
 This routine uses simple regex instead of Org::Parser, for faster performance.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -239,37 +217,31 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ascendant_match> => I<str|re>
 
-{en_US Only include headline whose ascendant matches this}.
+Only include headline whose ascendant matches this.
 
-{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
-}
 
 =item * B<input>* => I<str>
 
-{en_US 
 Value is either a string or an array of strings.
-}
 
 =item * B<is_done> => I<bool>
 
-{en_US Only include headline which is a done todo item}.
+Only include headline which is a done todo item.
 
 =item * B<is_todo> => I<bool>
 
-{en_US Only include headline which is a todo item}.
+Only include headline which is a todo item.
 
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
 
-{en_US Only include headline which matches this}.
+Only include headline which matches this.
 
-{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
-}
 
 =item * B<max_level> => I<int>
 
@@ -277,12 +249,10 @@ C</.../i> it is assumed to be a regex.
 
 =item * B<parent_match> => I<str|re>
 
-{en_US Only include headline whose parent matches this}.
+Only include headline whose parent matches this.
 
-{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
-}
 
 =back
 
@@ -291,11 +261,9 @@ Return value:  (array[str])
 
 =head2 list_org_todos(%args) -> array[str]
 
-{en_US List Org todos}.
+List Org todos.
 
-{en_US 
 This routine uses simple regex instead of Org::Parser, for faster performance.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -303,33 +271,27 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ascendant_match> => I<str|re>
 
-{en_US Only include headline whose ascendant matches this}.
+Only include headline whose ascendant matches this.
 
-{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
-}
 
 =item * B<input>* => I<str>
 
-{en_US 
 Value is either a string or an array of strings.
-}
 
 =item * B<is_done> => I<bool>
 
-{en_US Only include headline which is a done todo item}.
+Only include headline which is a done todo item.
 
 =item * B<level> => I<int>
 
 =item * B<match> => I<str|re>
 
-{en_US Only include headline which matches this}.
+Only include headline which matches this.
 
-{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
-}
 
 =item * B<max_level> => I<int>
 
@@ -337,12 +299,10 @@ C</.../i> it is assumed to be a regex.
 
 =item * B<parent_match> => I<str|re>
 
-{en_US Only include headline whose parent matches this}.
+Only include headline whose parent matches this.
 
-{en_US 
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
-}
 
 =back
 
