@@ -1,7 +1,7 @@
 package App::ListOrgTodos;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.32'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.33'; # VERSION
 
 use 5.010;
 use strict;
@@ -55,7 +55,7 @@ App::ListOrgTodos - List all todo items in all Org files
 
 =head1 VERSION
 
-This document describes version 0.32 of App::ListOrgTodos (from Perl distribution App-OrgUtils), released on 2015-08-17.
+This document describes version 0.33 of App::ListOrgTodos (from Perl distribution App-OrgUtils), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -68,7 +68,7 @@ This document describes version 0.32 of App::ListOrgTodos (from Perl distributio
 
 =head2 list_org_todos(%args) -> [status, msg, result, meta]
 
-{en_US List all todo items in all Org files}.
+List all todo items in all Org files.
 
 Arguments ('*' denotes required arguments):
 
@@ -76,26 +76,23 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cache_dir> => I<str>
 
-{en_US Cache Org parse result}.
+Cache Org parse result.
 
-{en_US 
 Since Org::Parser can spend some time to parse largish Org files, this is an
 option to store the parse result. Caching is turned on if this argument is set.
-}
 
 =item * B<detail> => I<bool> (default: 0)
 
-{en_US Show details instead of just titles}.
+Show details instead of just titles.
 
 =item * B<done> => I<bool> (default: 0)
 
-{en_US Only show todo items that are done}.
+Only show todo items that are done.
 
 =item * B<due_in> => I<int>
 
-{en_US Only show todo items that are (nearing|passed) due}.
+Only show todo items that are (nearing|passed) due.
 
-{en_US 
 If value is not set, then will use todo item's warning period (or, if todo item
 does not have due date or warning period in its due date, will use the default
 14 days).
@@ -106,103 +103,88 @@ if today is 2011-06-30 and due_in is set to 7, then todo item with due date
 <2011-07-10 > won't pass the filter (it's still 10 days in the future, larger
 than 7) but <2011-07-10 Sun +1y -14d> will (warning period 14 days is already
 passed by that time).
-}
 
 =item * B<files>* => I<array[str]>
 
 =item * B<from_level> => I<int> (default: 1)
 
-{en_US Only show headlines having this level as the minimum}.
+Only show headlines having this level as the minimum.
 
 =item * B<group_by_tags> => I<bool> (default: 0)
 
-{en_US Whether to group result by tags}.
+Whether to group result by tags.
 
-{en_US 
 If set to true, instead of returning a list, this function will return a hash of
 lists, keyed by tag: {tag1: [hl1, hl2, ...], tag2: [...]}. Note that some
 headlines might be listed more than once if it has several tags.
-}
 
 =item * B<has_tags> => I<array[str]>
 
-{en_US Only show headlines that have the specified tags}.
+Only show headlines that have the specified tags.
 
 =item * B<lacks_tags> => I<array[str]>
 
-{en_US Only show headlines that don't have the specified tags}.
+Only show headlines that don't have the specified tags.
 
 =item * B<maximum_priority> => I<str>
 
-{en_US Only show todo items that have at most this priority}.
+Only show todo items that have at most this priority.
 
-{en_US 
 Note that the default priority list is [A, B, C] (A being the highest) and it
 can be customized using the C<#+PRIORITIES> setting.
-}
 
 =item * B<minimum_priority> => I<str>
 
-{en_US Only show todo items that have at least this priority}.
+Only show todo items that have at least this priority.
 
-{en_US 
 Note that the default priority list is [A, B, C] (A being the highest) and it
 can be customized using the C<#+PRIORITIES> setting.
-}
 
 =item * B<priority> => I<str>
 
-{en_US Only show todo items that have this priority}.
+Only show todo items that have this priority.
 
 =item * B<sort> => I<str|code> (default: "due_date")
 
-{en_US Specify sorting}.
+Specify sorting.
 
-{en_US 
 If string, must be one of 'due_date', '-due_date' (descending).
 
 If code, sorting code will get [REC, DUE_DATE, HL] as the items to compare,
 where REC is the final record that will be returned as final result (can be a
 string or a hash, if 'detail' is enabled), DUE_DATE is the DateTime object (if
 any), and HL is the Org::Headline object.
-}
 
 =item * B<state> => I<str>
 
-{en_US Only show todo items that have this state}.
+Only show todo items that have this state.
 
 =item * B<time_zone> => I<str>
 
-{en_US Will be passed to parser's options}.
+Will be passed to parser's options.
 
-{en_US 
 If not set, TZ environment variable will be picked as default.
-}
 
 =item * B<to_level> => I<int>
 
-{en_US Only show headlines having this level as the maximum}.
+Only show headlines having this level as the maximum.
 
 =item * B<today> => I<obj>
 
-{en_US Assume today's date}.
+Assume today's date.
 
-{en_US 
 You can provide Unix timestamp or DateTime object. If you provide a DateTime
 object, remember to set the correct time zone.
-}
 
 =item * B<with_unknown_priority> => I<bool>
 
-{en_US Also show items with no/unknown priority}.
+Also show items with no/unknown priority.
 
-{en_US 
 Relevant only when used with C<minimum_priority> and/or C<maximum_priority>.
 
 If this option is turned on, todo items that does not have any priority or have
 unknown priorities will I<still> be included. Otherwise they will not be
 included.
-}
 
 =back
 
